<template>
    <div class="full-page bg" element-loading-text="数据加载中..." element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)" v-loading.fullscreen.lock="markLoading">
        <el-row :gutter="10" class="main-table-container">
            <el-col :span="24" class="table-container" ref="contentPanel" style="padding: 20px">
                <el-tabs v-model="activeName">
                    <el-tab-pane label="区县推进情况核准" name="first">
                        <el-table stripe size="mini" v-loading="tableLoading" ref="multipleSelection" :data="tableData"
                            height="calc(100% - 50px)" :style="{ width: '100%' }" :default-sort="{
                                prop: 'status',
                                order: 'ascending',
                            }">
                            <el-table-column label="序号" type="index" width="150" align="center"></el-table-column>
                            <el-table-column prop="unitName" show-overflow-tooltip min-width="250" label="上报区县"
                                align="center">
                            </el-table-column>
                            <el-table-column prop="updateTime" show-overflow-tooltip min-width="160" label="最近更新时间"
                                align="center">
                                <template v-slot="{ row }">
                                    <span v-if="row.updateTime && row.status > 2">
                                        {{ row.updateTime }}
                                    </span>
                                    <span v-else> ---- </span>
                                </template>
                            </el-table-column>
                            <el-table-column show-overflow-tooltip min-width="150" align="center"
                                :label="$t('common.operation')">
                                <template v-slot="{ row }">
                                    <el-link v-if="row.status === 3" icon="el-icon-s-check" type="primary"
                                        :underline="false" class="cloumn-btn" @click="openDialog(row, '核准')">
                                        核准
                                    </el-link>
                                    <el-link v-if="row.status === 4" icon="el-icon-view" type="success" :underline="false"
                                        class="success-btn" @click="openDialog(row, '详情')">
                                        查看
                                    </el-link>
                                    <el-link v-if="!row.id" type="danger" :underline="false">
                                        待更新
                                    </el-link>
                                </template>
                            </el-table-column>
                        </el-table>
                        <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="pageResult"
                            @size-change="handleSizeChange" @current-change="handleCurrentChange" />
                        <el-dialog :title="title" :visible.sync="dialogVisible" top="5vh" width="90%"
                            :before-close="handleClose">
                            <addForm @closeDialog="handleClose" :title="title" :reqId="reqId" :unitId="unitId"
                                ref="addform"></addForm>
                        </el-dialog>
                    </el-tab-pane>
                    <el-tab-pane label="区县推进情况查询" name="second">
                        <searchPromotion></searchPromotion>
                    </el-tab-pane>
                    <el-tab-pane label="区县推进情况全量查询" name="third">
                        <searchFullLibrary></searchFullLibrary>
                    </el-tab-pane>
                </el-tabs>
            </el-col>
        </el-row>
    </div>
</template>
    
<script>
import _ from 'lodash'
import pagination from '@/components/pagination'
import { TableMixin } from '@/mixins/tableMixin'
import apilist from '@/api/digitalApi'
import utils from '@/utils.js'
import addForm from './components/addForm.vue'
import searchPromotion from './components/searchPromotion.vue'
import searchFullLibrary from './components/searchFullLibrary.vue'
export default {
    name: 'AdvanceApproval',
    components: {
        pagination,
        addForm,
        searchPromotion,
        searchFullLibrary,
    },
    mixins: [TableMixin],
    data() {
        return {
            activeName: 'first',
            dialogVisible: false,
            markLoading: false,
            tableMaxHeight: 400,
            tableData: [],
            pageResult: {
                page: 1,
                pageSize: 50,
                total: 0,
            },
            reqData: {
                pageBean: {
                    page: 1,
                    pageSize: 50,
                    showTotal: true,
                },
                // querys: [{
                //     group: 'main',
                //     operation: 'IN',
                //     parentGroup: '',
                //     property: 'c.STATUS_',
                //     relation: 'AND',
                //     value: [0,1,2,3,4]
                // }]
            },
            tableLoading: false,
            deleteIds: '',
            reqId: '',
            unitId: '',
            title: '核准'
        }
    },

    created() {
        this.getData(this.reqData)
    },
    methods: {
        getTableData(val) {
            if (this.auditStatus != val) {
                this.auditStatus = val
                this.getStatusList()
            }
        },
        getStatusList: _.debounce(function () {
            this.reqData.pageBean.page = 1
            this.reqData.querys[0].value = this.auditStatus
                ? [2, 3, 4, 5, 6, 7]
                : [1]
        }, 500),
        //获取数据
        getData(data) {
            this.tableLoading = true
            apilist.getTableData(data, (res) => {
                this.pageResult.total = res.total
                this.tableLoading = false
                this.tableData = res.rows
            })
        },

        // 查看详情 编辑  添加
        openDialog(item, title) {
            let { id, unitId } = item
            // this.reqId = id
            // this.unitId = unitId
            // this.title = title
            this.dialogVisible = true
            this.$nextTick(() => {
                this.$refs.addform.reqId = id
                this.$refs.addform.unitId = unitId
                this.$refs.addform.title = title
                // this.$refs.addform.date = createTime
                this.$refs.addform.getDetail(id)
            })
        },
        handleClose(e) {
            this.reqId = ''
            this.unitId = ''
            this.$refs.addform.oldData = null
            this.$refs.addform.copyData = null
            this.dialogVisible = false
            if (e === 'refresh') {
                this.getData(this.reqData)
            }
        },
        // 撤回
        revocation(item) {
            let data = {
                status: 1,
                id: item.recId,
            }
            this.$confirm('确认执行撤销操作吗？', '提示', {
                confirmButtonText: '确定',
                cancelButtonText: '取消',
                type: 'error',
            }).then(() => {
                this.markLoading = true
                data.approvalResults = 2
                pilot.updateMunStatus(data, (res) => {
                    if (res.state) {
                        this.$message.success('撤销操作成功')
                    }
                    this.markLoading = false
                })
            })
        },

        getDictName(code, value) {
            return utils.getDictName(code, value)
        },

        handleCurrentChange(page) {
            this.reqData.pageBean = { ...this.reqData.pageBean, page }
            this.getData(this.reqData)
        },
        handleSizeChange(pageSize) {
            this.reqData.pageBean = { ...this.reqData.pageBean, pageSize }
            this.getData(this.reqData)
        },
    },
}
</script>
    
<style lang="scss" scoped>
/deep/.upload-file {
    .el-dialog__body {
        height: auto !important;
    }
}

/deep/.el-dialog__body {
    max-height: 75vh;
    height: 75vh;

    .form-collapse {
        max-height: 70vh;
    }
}

.main-table-container {
    height: 100%;
    margin: 0 !important;
}

.common-tree-container {
    // height: calc(100% - 70px);
    margin-top: 0.52083vw;
    padding: 1.04167vw 1.04167vw;
    background-color: #fff;
    position: relative;
    box-sizing: border-box;
    overflow-y: auto;
    border-radius: 20px;
    box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
    display: flex;
    align-items: center;

    i {
        font-size: 16px;
        margin-left: 5px;
        font-weight: 600;
        cursor: pointer;
    }
}

.move-tree /deep/ .el-tree {
    height: 90%;
    overflow-y: auto;
    border: none;
}

.cloumn-btn {
    border: 1px solid #2761ff;
    padding: 3px 10px;
    border-radius: 5px;

    &:nth-child(1) {
        margin-right: 5px;
    }

    &:nth-child(1):hover {
        background-color: #2761ff;
        color: #fff;
    }

    &:nth-child(2):hover {
        background-color: #2761ff;
        color: #fff;
        border-color: #2761ff;
    }

    /deep/ i,
    span {
        font-size: 14px;
    }
}

.success-btn {
    border: 1px solid #67c23a;
    padding: 3px 10px;
    border-radius: 5px;

    &:hover {
        background-color: #67c23a;
        color: #fff;
    }
}

/deep/ .el-tree-node__content {
    padding: 5px 0;
}

.qx-tag {
    cursor: pointer;
    user-select: none;
}

.search-container {
    /deep/ .el-form-item__label {
        line-height: 58px;
        white-space: nowrap !important;
    }
}

.el-dropdown-link {
    cursor: pointer;
    font-size: 0.72917vw;
    font-weight: bold;
    color: #3c4353;
}

/deep/ .el-tabs__content {
    height: calc(100% - 44px);

    .el-tab-pane {
        height: 100%;
    }
}
</style>
    